##############################################################################
#
# Copyright (c) 2010 ViFiB SARL and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################


import argparse
import os
import subprocess
import sys


def generateCertificate(certificate_file, key_file, common_name):
  if os.path.lexists(certificate_file):
    raise ValueError("Certificate %r exists, will not overwrite." %
      certificate_file)
  if os.path.lexists(key_file):
    raise ValueError("Key %r exists, will not overwrite." %
      key_file)

  subj = '/CN=%s' % common_name
  subprocess.check_call(["openssl", "req", "-x509", "-nodes", "-days", "365",
    "-subj", subj, "-newkey", "rsa:1024", "-keyout", key_file, "-out",
    certificate_file])


def run(*args):
  parser = argparse.ArgumentParser()
  parser.add_argument('certificate_file', type=str,
    help='Certificate file to generate.')

  parser.add_argument('key_file', type=str,
    help='Key file to generate.')
  parser.add_argument('common_name', type=str, help="Common Name")

  option = parser.parse_args(list(args) or sys.argv[1:])
  generateCertificate(option.certificate_file,
    option.key_file, option.common_name)
